@@ -35,9 +35,10 @@
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
 #include <gconf/gconf-client.h>
-#include <pk-control.h>
+#include <packagekit-glib/packagekit.h>
 
 #include "egg-debug.h"
+#include "egg-string.h"
 #include "egg-dbus-monitor.h"
 
 #include "gpk-common.h"
@@ -50,6 +51,7 @@ static void     gpk_auto_refresh_finalize	(GObject            *object);
 
 #define GPK_AUTO_REFRESH_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPK_TYPE_AUTO_REFRESH, GpkAutoRefreshPrivate))
 #define GPK_AUTO_REFRESH_PERIODIC_CHECK		60*60	/* force check for updates every this much time */
+#define GPK_UPDATES_LOGIN_TIMEOUT		3	/* seconds */
 
 #define GS_DBUS_SERVICE				"org.gnome.ScreenSaver"
 #define GS_DBUS_PATH				"/org/gnome/ScreenSaver"
@@ -73,8 +75,9 @@ struct GpkAutoRefreshPrivate
 	gboolean		 session_idle;
 	gboolean		 on_battery;
 	gboolean		 network_active;
-	gboolean		 session_delay;
-	gboolean		 sent_get_updates;
+	gboolean		 force_get_updates_login;
+	guint			 force_get_updates_login_timeout_id;
+	guint			 timeout_id;
 	EggDbusMonitor		*monitor_gs;
 	EggDbusMonitor		*monitor_gpm;
 	GConfClient		*gconf_client;
@@ -278,10 +281,19 @@ gpk_auto_refresh_maybe_get_updates (GpkAutoRefresh *arefresh)
 
 	g_return_val_if_fail (GPK_IS_AUTO_REFRESH (arefresh), FALSE);
 
+	if (!arefresh->priv->force_get_updates_login) {
+		arefresh->priv->force_get_updates_login = TRUE;
+		if (gconf_client_get_bool (arefresh->priv->gconf_client, GPK_CONF_FORCE_GET_UPDATES_LOGIN, NULL)) {
+			egg_debug ("forcing get update due to GConf");
+			gpk_auto_refresh_signal_get_updates (arefresh);
+			return TRUE;
+		}
+	}
+
 	/* get this each time, as it may have changed behind out back */
 	thresh = gpk_auto_refresh_convert_frequency_text (arefresh, GPK_CONF_FREQUENCY_GET_UPDATES);
 	if (thresh == 0) {
-		egg_debug ("not when policy is to never refresh");
+		egg_debug ("not when policy is set to never get updates");
 		return FALSE;
 	}
 
@@ -318,7 +330,7 @@ gpk_auto_refresh_maybe_get_upgrades (GpkAutoRefresh *arefresh)
 	/* get this each time, as it may have changed behind out back */
 	thresh = gpk_auto_refresh_convert_frequency_text (arefresh, GPK_CONF_FREQUENCY_GET_UPGRADES);
 	if (thresh == 0) {
-		egg_debug ("not when policy is to never refresh");
+		egg_debug ("not when policy is set to never check for upgrades");
 		return FALSE;
 	}
 
@@ -340,19 +352,29 @@ gpk_auto_refresh_maybe_get_upgrades (GpkAutoRefresh *arefresh)
 	return TRUE;
 }
 
+/**
+ * gpk_auto_refresh_change_state_cb:
+ **/
+static gboolean
+gpk_auto_refresh_change_state_cb (GpkAutoRefresh *arefresh)
+{
+	/* check all actions */
+	gpk_auto_refresh_maybe_refresh_cache (arefresh);
+	gpk_auto_refresh_maybe_get_updates (arefresh);
+	gpk_auto_refresh_maybe_get_upgrades (arefresh);
+	return FALSE;
+}
+
 /**
  * gpk_auto_refresh_change_state:
  **/
 static gboolean
 gpk_auto_refresh_change_state (GpkAutoRefresh *arefresh)
 {
-	g_return_val_if_fail (GPK_IS_AUTO_REFRESH (arefresh), FALSE);
+	gboolean force;
+	guint value;
 
-	/* we shouldn't do this early in the session startup */
-	if (!arefresh->priv->session_delay) {
-		egg_debug ("not when this early in the session");
-		return FALSE;
-	}
+	g_return_val_if_fail (GPK_IS_AUTO_REFRESH (arefresh), FALSE);
 
 	/* no point continuing if we have no network */
 	if (!arefresh->priv->network_active) {
@@ -360,21 +382,48 @@ gpk_auto_refresh_change_state (GpkAutoRefresh *arefresh)
 		return FALSE;
 	}
 
-	/* we do this to get an icon at startup */
-	if (!arefresh->priv->sent_get_updates) {
-		gpk_auto_refresh_signal_get_updates (arefresh);
-		arefresh->priv->sent_get_updates = TRUE;
-		return TRUE;
+	/* only force a check if the user REALLY, REALLY wants to break
+	 * set policy and have an update at startup */
+	if (!arefresh->priv->force_get_updates_login) {
+		force = gconf_client_get_bool (arefresh->priv->gconf_client, GPK_CONF_FORCE_GET_UPDATES_LOGIN, NULL);
+		if (force) {
+			/* don't immediately send the signal, if we are called during object initialization
+			 * we need to wait until upper layers  finish hooking up to the signal first. */
+			if (arefresh->priv->force_get_updates_login_timeout_id == 0)
+				arefresh->priv->force_get_updates_login_timeout_id =
+					g_timeout_add_seconds (GPK_UPDATES_LOGIN_TIMEOUT, (GSourceFunc) gpk_auto_refresh_maybe_get_updates, arefresh);
+		}
 	}
 
-	/* try to do both */
-	gpk_auto_refresh_maybe_refresh_cache (arefresh);
-	gpk_auto_refresh_maybe_get_updates (arefresh);
-	gpk_auto_refresh_maybe_get_upgrades (arefresh);
+	/* wait a little time for things to settle down */
+	if (arefresh->priv->timeout_id != 0)
+		g_source_remove (arefresh->priv->timeout_id);
+	value = gconf_client_get_int (arefresh->priv->gconf_client, GPK_CONF_SESSION_STARTUP_TIMEOUT, NULL);
+	egg_debug ("defering action for %i seconds", value);
+	arefresh->priv->timeout_id = g_timeout_add_seconds (value, (GSourceFunc) gpk_auto_refresh_change_state_cb, arefresh);
 
 	return TRUE;
 }
 
+/**
+ * gpk_auto_refresh_gconf_key_changed_cb:
+ *
+ * We might have to do things when the gconf keys change; do them here.
+ **/
+static void
+gpk_auto_refresh_gconf_key_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, GpkAutoRefresh *arefresh)
+{
+	g_return_if_fail (GPK_IS_AUTO_REFRESH (arefresh));
+	if (egg_strequal (entry->key, GPK_CONF_SESSION_STARTUP_TIMEOUT) ||
+	    egg_strequal (entry->key, GPK_CONF_FORCE_GET_UPDATES_LOGIN) ||
+	    egg_strequal (entry->key, GPK_CONF_FREQUENCY_GET_UPDATES) ||
+	    egg_strequal (entry->key, GPK_CONF_FREQUENCY_GET_UPGRADES) ||
+	    egg_strequal (entry->key, GPK_CONF_FREQUENCY_REFRESH_CACHE) ||
+	    egg_strequal (entry->key, GPK_CONF_AUTO_UPDATE) ||
+	    egg_strequal (entry->key, GPK_CONF_UPDATE_BATTERY))
+		gpk_auto_refresh_change_state (arefresh);
+}
+
 /**
  * gpk_auto_refresh_idle_cb:
  **/
@@ -385,7 +434,8 @@ gpk_auto_refresh_idle_cb (DBusGProxy *proxy, gboolean is_idle, GpkAutoRefresh *a
 
 	egg_debug ("setting is_idle %i", is_idle);
 	arefresh->priv->session_idle = is_idle;
-	gpk_auto_refresh_change_state (arefresh);
+	if (arefresh->priv->session_idle)
+		gpk_auto_refresh_change_state (arefresh);
 }
 
 /**
@@ -398,7 +448,8 @@ gpk_auto_refresh_on_battery_cb (DBusGProxy *proxy, gboolean on_battery, GpkAutoR
 
 	egg_debug ("setting on_battery %i", on_battery);
 	arefresh->priv->on_battery = on_battery;
-	gpk_auto_refresh_change_state (arefresh);
+	if (!arefresh->priv->on_battery)
+		gpk_auto_refresh_change_state (arefresh);
 }
 
 /**
@@ -421,7 +472,8 @@ gpk_auto_refresh_network_status_changed_cb (PkControl *control, PkNetworkEnum st
 
 	arefresh->priv->network_active = (state == PK_NETWORK_ENUM_ONLINE);
 	egg_debug ("setting online %i", arefresh->priv->network_active);
-	gpk_auto_refresh_change_state (arefresh);
+	if (arefresh->priv->network_active)
+		gpk_auto_refresh_change_state (arefresh);
 }
 
 /**
@@ -444,32 +496,6 @@ gpk_auto_refresh_timeout_cb (gpointer user_data)
 	return TRUE;
 }
 
-/**
- * gpk_auto_refresh_check_delay_cb:
- **/
-static gboolean
-gpk_auto_refresh_check_delay_cb (gpointer user_data)
-{
-	GpkAutoRefresh *arefresh = GPK_AUTO_REFRESH (user_data);
-
-	g_return_val_if_fail (GPK_IS_AUTO_REFRESH (arefresh), FALSE);
-
-	/* debug so we can catch polling */
-	egg_debug ("polling check");
-
-	/* we have waited enough */
-	if (!arefresh->priv->session_delay) {
-		egg_debug ("setting session delay TRUE");
-		arefresh->priv->session_delay = TRUE;
-	}
-
-	/* if we failed to do the refresh cache at first boot, we'll pick up an event */
-	gpk_auto_refresh_change_state (arefresh);
-
-	/* we don't want to do this timer again as we sent the signal */
-	return FALSE;
-}
-
 /**
  * pk_connection_gpm_changed_cb:
  **/
@@ -568,7 +594,6 @@ pk_connection_gs_changed_cb (EggDbusMonitor *egg_dbus_monitor, gboolean connecte
 static void
 gpk_auto_refresh_init (GpkAutoRefresh *arefresh)
 {
-	guint value;
 	GError *error = NULL;
 	PkNetworkEnum state;
 
@@ -576,8 +601,9 @@ gpk_auto_refresh_init (GpkAutoRefresh *arefresh)
 	arefresh->priv->on_battery = FALSE;
 	arefresh->priv->session_idle = FALSE;
 	arefresh->priv->network_active = FALSE;
-	arefresh->priv->session_delay = FALSE;
-	arefresh->priv->sent_get_updates = FALSE;
+	arefresh->priv->force_get_updates_login = FALSE;
+	arefresh->priv->timeout_id = 0;
+	arefresh->priv->force_get_updates_login_timeout_id = 0;
 
 	arefresh->priv->proxy_gs = NULL;
 	arefresh->priv->proxy_gpm = NULL;
@@ -585,6 +611,13 @@ gpk_auto_refresh_init (GpkAutoRefresh *arefresh)
 	/* we need to know the updates frequency */
 	arefresh->priv->gconf_client = gconf_client_get_default ();
 
+	/* watch gnome-packagekit keys */
+	gconf_client_add_dir (arefresh->priv->gconf_client, GPK_CONF_DIR,
+			      GCONF_CLIENT_PRELOAD_NONE, NULL);
+	gconf_client_notify_add (arefresh->priv->gconf_client, GPK_CONF_DIR,
+				 (GConfClientNotifyFunc) gpk_auto_refresh_gconf_key_changed_cb,
+				 arefresh, NULL, NULL);
+
 	/* we need to query the last cache refresh time */
 	arefresh->priv->control = pk_control_new ();
 	g_signal_connect (arefresh->priv->control, "network-state-changed",
@@ -616,9 +649,8 @@ gpk_auto_refresh_init (GpkAutoRefresh *arefresh)
 	/* we check this in case we miss one of the async signals */
 	g_timeout_add_seconds (GPK_AUTO_REFRESH_PERIODIC_CHECK, gpk_auto_refresh_timeout_cb, arefresh);
 
-	/* wait a little bit for login to quiece, even if everything is okay */
-	value = gconf_client_get_int (arefresh->priv->gconf_client, GPK_CONF_SESSION_STARTUP_TIMEOUT, NULL);
-	g_timeout_add_seconds (value, gpk_auto_refresh_check_delay_cb, arefresh);
+	/* check system state */
+	gpk_auto_refresh_change_state (arefresh);
 }
 
 /**
@@ -635,6 +667,11 @@ gpk_auto_refresh_finalize (GObject *object)
 	arefresh = GPK_AUTO_REFRESH (object);
 	g_return_if_fail (arefresh->priv != NULL);
 
+	if (arefresh->priv->timeout_id != 0)
+		g_source_remove (arefresh->priv->timeout_id);
+	if (arefresh->priv->force_get_updates_login_timeout_id != 0)
+		g_source_remove (arefresh->priv->force_get_updates_login_timeout_id);
+
 	g_object_unref (arefresh->priv->control);
 	g_object_unref (arefresh->priv->monitor_gs);
 	g_object_unref (arefresh->priv->monitor_gpm);
