@@ -37,16 +37,7 @@
 #include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
 #include <libnotify/notify.h>
-
-#include <pk-client.h>
-#include <pk-control.h>
-#include <pk-common.h>
-#include <pk-task-list.h>
-#include <pk-connection.h>
-#include <pk-package-id.h>
-#include <pk-package-ids.h>
-#include <pk-package-list.h>
-#include <pk-distro-upgrade-obj.h>
+#include <packagekit-glib/packagekit.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
@@ -65,6 +56,9 @@ static void     gpk_check_update_finalize	(GObject	     *object);
 
 #define GPK_CHECK_UPDATE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPK_TYPE_CHECK_UPDATE, GpkCheckUpdatePrivate))
 
+/* the maximum number of lines of data on the libnotify widget */
+#define GPK_CHECK_UPDATE_MAX_NUMBER_SECURITY_ENTRIES	7
+
 struct GpkCheckUpdatePrivate
 {
 	GpkSmartIcon		*sicon;
@@ -80,6 +74,7 @@ struct GpkCheckUpdatePrivate
 	gboolean		 cache_okay;
 	gboolean		 cache_update_in_progress;
 	gboolean		 get_updates_in_progress;
+	guint			 number_updates_critical_last_shown;
 	NotifyNotification	*notification_updates_available;
 	GPtrArray		*important_updates_array;
 };
@@ -161,6 +156,7 @@ gpk_check_update_about_dialog_url_cb (GtkAboutDialog *about, const char *address
 						       GTK_DIALOG_MODAL,
 						       GTK_MESSAGE_INFO,
 						       GTK_BUTTONS_OK,
+						       /* TRANSLATORS: normally a packaging error, cannot launch link */
 						       _("Failed to show url"));
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (error_dialog),
 							  "%s", error->message);
@@ -218,6 +214,7 @@ gpk_check_update_show_about_cb (GtkMenuItem *item, gpointer data)
 			       "version", VERSION,
 			       "copyright", "Copyright \xc2\xa9 2007-2008 Richard Hughes",
 			       "license", license_trans,
+				/* TRANSLATORS: website label */
 			       "website-label", _("PackageKit Website"),
 			       "website", "www.packagekit.org",
 			       "comments", "PackageKit",
@@ -243,7 +240,7 @@ gpk_check_update_popup_menu_cb (GtkStatusIcon *status_icon, guint button, guint3
 
 	egg_debug ("icon right clicked");
 
-	/* Preferences */
+	/* TRANSLATORS: context menu to open the preferences */
 	item = gtk_image_menu_item_new_with_mnemonic (_("_Preferences"));
 	image = gtk_image_new_from_icon_name (GTK_STOCK_PREFERENCES, GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
@@ -255,7 +252,7 @@ gpk_check_update_popup_menu_cb (GtkStatusIcon *status_icon, guint button, guint3
 	item = gtk_separator_menu_item_new ();
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
-	/* No help yet */
+	/* TRANSLATORS: context menu to open the offline help file */
 	item = gtk_image_menu_item_new_with_mnemonic (_("_Help"));
 	image = gtk_image_new_from_icon_name (GTK_STOCK_HELP, GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
@@ -263,7 +260,7 @@ gpk_check_update_popup_menu_cb (GtkStatusIcon *status_icon, guint button, guint3
 			  G_CALLBACK (gpk_check_update_show_help_cb), icon);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
-	/* About */
+	/* TRANSLATORS: context menu to show the about screen */
 	item = gtk_image_menu_item_new_with_mnemonic (_("_About"));
 	image = gtk_image_new_from_icon_name (GTK_STOCK_ABOUT, GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
@@ -306,6 +303,10 @@ gpk_check_update_update_system (GpkCheckUpdate *cupdate)
 	gboolean ret;
 	ret = gpk_client_update_system (cupdate->priv->gclient_update_system, NULL);
 
+	/* this isn't valid anymore */
+	if (ret)
+		cupdate->priv->number_updates_critical_last_shown = 0;
+
 	/* we failed, show the icon */
 	if (!ret) {
 		gpk_smart_icon_set_icon_name (cupdate->priv->sicon, NULL);
@@ -353,7 +354,7 @@ gpk_check_update_activate_update_cb (GtkStatusIcon *status_icon, GpkCheckUpdate
 
 	egg_debug ("icon left clicked");
 
-	/* show updates */
+	/* TRANSLATORS: context menu to execute the update viewer  */
 	item = gtk_image_menu_item_new_with_mnemonic (_("_Show Updates"));
 	image = gtk_image_new_from_icon_name (GPK_ICON_SOFTWARE_UPDATE, GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
@@ -361,7 +362,7 @@ gpk_check_update_activate_update_cb (GtkStatusIcon *status_icon, GpkCheckUpdate
 			  G_CALLBACK (gpk_check_update_menuitem_show_updates_cb), icon);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
-	/* update system */
+	/* TRANSLATORS: context menu to update any pending updates */
 	item = gtk_image_menu_item_new_with_mnemonic (_("_Update System Now"));
 	image = gtk_image_new_from_icon_name (GPK_ICON_SOFTWARE_UPDATE_AVAILABLE, GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
@@ -410,6 +411,9 @@ gpk_check_update_libnotify_cb (NotifyNotification *notification, gchar *action,
 			egg_warning ("Individual updates failed: %s", error->message);
 			g_error_free (error);
 		}
+		/* this isn't valid anymore */
+		if (ret)
+			cupdate->priv->number_updates_critical_last_shown = 0;
 		g_strfreev (package_ids);
 
 	} else if (egg_strequal (action, "do-not-show-notify-critical")) {
@@ -447,6 +451,16 @@ gpk_check_update_critical_updates_warning (GpkCheckUpdate *cupdate, const gchar
 		return;
 	}
 
+	/* if the number of critical updates is the same as the last notification,
+	 * then skip the notifcation as we don't want to bombard the user every hour */
+	if (array->len == cupdate->priv->number_updates_critical_last_shown) {
+		egg_debug ("ignoring as user ignored last warning");
+		return;
+	}
+
+	/* save for comparison later */
+	cupdate->priv->number_updates_critical_last_shown = array->len;
+
 	/* save for later */
 	if (cupdate->priv->important_updates_array != NULL) {
 		g_ptr_array_foreach (cupdate->priv->important_updates_array, (GFunc) g_free, NULL);
@@ -458,11 +472,12 @@ gpk_check_update_critical_updates_warning (GpkCheckUpdate *cupdate, const gchar
 		g_ptr_array_add (cupdate->priv->important_updates_array, g_strdup (package_id));
 	}
 
-	/* format title */
+	/* TRANSLATORS: title in the libnotify popup */
 	title = ngettext ("Security update available", "Security updates available", array->len);
 
 	/* format message text */
 	string = g_string_new ("");
+	/* TRANSLATORS: message when there are security updates */
 	g_string_append (string, ngettext ("The following important update is available for your computer:",
 					   "The following important updates are available for your computer:", array->len));
 	g_string_append (string, "\n\n");
@@ -484,10 +499,13 @@ gpk_check_update_critical_updates_warning (GpkCheckUpdate *cupdate, const gchar
 	notify_notification_set_timeout (notification, NOTIFY_EXPIRES_NEVER);
 	notify_notification_set_urgency (notification, NOTIFY_URGENCY_CRITICAL);
 	notify_notification_add_action (notification, "update-just-security",
-					_("Install security updates"), gpk_check_update_libnotify_cb, cupdate, NULL);
+					/* TRANSLATORS: button: only security updates */
+					_("Install only security updates"), gpk_check_update_libnotify_cb, cupdate, NULL);
 	notify_notification_add_action (notification, "update-all-packages",
+					/* TRANSLATORS: button: all pending updates */
 					_("Install all updates"), gpk_check_update_libnotify_cb, cupdate, NULL);
 	notify_notification_add_action (notification, "do-not-show-notify-critical",
+					/* TRANSLATORS: button: hide forever */
 					_("Do not show this again"), gpk_check_update_libnotify_cb, cupdate, NULL);
 	ret = notify_notification_show (notification, &error);
 	if (!ret) {
@@ -596,15 +614,18 @@ gpk_check_update_check_on_battery (GpkCheckUpdate *cupdate)
 		return FALSE;
 	}
 
-	/* do the bubble */
-	message = _("Automatic updates are not being installed as the computer is on battery power");
-	notification = notify_notification_new (_("Will not install updates"), message, "help-browser", NULL);
+	/* TRANSLATORS: policy says update, but we are on battery and so prompt */
+	message = _("Automatic updates are not being installed as the computer is running on battery power");
+	/* TRANSLATORS: informs user will not install by default */
+	notification = notify_notification_new (_("Updates not installed"), message, "help-browser", NULL);
 	notify_notification_set_timeout (notification, 15000);
 	notify_notification_set_urgency (notification, NOTIFY_URGENCY_LOW);
 	notify_notification_add_action (notification, "do-not-show-update-not-battery",
+					/* TRANSLATORS: hide this warning type forever */
 					_("Do not show this warning again"), gpk_check_update_libnotify_cb, cupdate, NULL);
 	notify_notification_add_action (notification, "update-all-packages",
-					_("Do the updates anyway"), gpk_check_update_libnotify_cb, cupdate, NULL);
+					/* TRANSLATORS: to hell with my battery life, just do it */
+					_("Install the updates anyway"), gpk_check_update_libnotify_cb, cupdate, NULL);
 	ret = notify_notification_show (notification, &error);
 	if (!ret) {
 		egg_warning ("error: %s", error->message);
@@ -645,6 +666,7 @@ gpk_check_update_query_updates (GpkCheckUpdate *cupdate)
 	guint length;
 	guint i;
 	guint more;
+	guint showing = 0;
 	gboolean ret = FALSE;
 	GString *status_security;
 	GString *status_tooltip;
@@ -682,6 +704,13 @@ gpk_check_update_query_updates (GpkCheckUpdate *cupdate)
 		return FALSE;
 	}
 
+	/* sort by name */
+	pk_package_list_sort (list);
+
+	/* filter out the same package with multiple architectures */
+	pk_package_list_set_fuzzy_arch (list, TRUE);
+	pk_obj_list_remove_duplicate (PK_OBJ_LIST(list));
+
 	/* we have updates to process */
 	status_security = g_string_new ("");
 	status_tooltip = g_string_new ("");
@@ -698,20 +727,28 @@ gpk_check_update_query_updates (GpkCheckUpdate *cupdate)
 		goto out;
 	}
 
-	/* find the security updates */
+	/* find the security updates first */
 	for (i=0; i<length; i++) {
 		obj = pk_package_list_get_obj (list, i);
 		if (obj->info == PK_INFO_ENUM_SECURITY) {
 			/* add to array */
 			package_id = pk_package_id_to_string (obj->id);
 			g_ptr_array_add (security_array, package_id);
-			g_string_append_printf (status_security, "<b>%s</b> - %s\n",
-						obj->id->name, obj->summary);
 		}
+	}
 
-		/* don't have a huge notification that won't fit on the screen */
-		if (security_array->len > 10) {
-			more = length - security_array->len;
+	/* get the security update text */
+	for (i=0; i<length; i++) {
+		obj = pk_package_list_get_obj (list, i);
+		if (obj->info != PK_INFO_ENUM_SECURITY)
+			continue;
+
+		/* don't use a huge notification that won't fit on the screen */
+		g_string_append_printf (status_security, "<b>%s</b> - %s\n",
+					obj->id->name, obj->summary);
+		if (++showing == GPK_CHECK_UPDATE_MAX_NUMBER_SECURITY_ENTRIES) {
+			more = security_array->len - showing;
+			/* TRANSLATORS: we have a notification that won't fit, so append on how many other we are not showing */
 			g_string_append_printf (status_security, ngettext ("and %d other security update",
 									   "and %d other security updates", more), more);
 			g_string_append (status_security, "...\n");
@@ -732,9 +769,9 @@ gpk_check_update_query_updates (GpkCheckUpdate *cupdate)
 	gpk_smart_icon_pulse (cupdate->priv->sicon);
 
 	/* make tooltip */
-	if (status_security->len != 0) {
+	if (status_security->len != 0)
 		g_string_set_size (status_security, status_security->len-1);
-	}
+	/* TRANSLATORS: tooltip: how many updates are waiting to be applied */
 	g_string_append_printf (status_tooltip, ngettext ("There is %d update pending",
 							  "There are %d updates pending", length), length);
 	gtk_status_icon_set_tooltip (GTK_STATUS_ICON (cupdate->priv->sicon), status_tooltip->str);
@@ -774,6 +811,9 @@ gpk_check_update_query_updates (GpkCheckUpdate *cupdate)
 			egg_warning ("Individual updates failed: %s", error->message);
 			g_error_free (error);
 		}
+		/* this isn't valid anymore */
+		if (ret)
+			cupdate->priv->number_updates_critical_last_shown = 0;
 		g_strfreev (package_ids);
 		goto out;
 	}
@@ -960,7 +1000,7 @@ gpk_check_update_auto_get_upgrades_cb (GpkAutoRefresh *arefresh, GpkCheckUpdate
 	if (string->len != 0)
 		g_string_set_size (string, string->len-1);
 
-	/* do the bubble */
+	/* TRANSLATORS: a distro update is available, e.g. Fedora 8 to Fedora 9 */
 	title = _("Distribution upgrades available");
 	notification = notify_notification_new (title, string->str, "help-browser", NULL);
 	if (notification == NULL) {
@@ -970,8 +1010,10 @@ gpk_check_update_auto_get_upgrades_cb (GpkAutoRefresh *arefresh, GpkCheckUpdate
 	notify_notification_set_timeout (notification, NOTIFY_EXPIRES_NEVER);
 	notify_notification_set_urgency (notification, NOTIFY_URGENCY_NORMAL);
 	notify_notification_add_action (notification, "upgrade-info",
+					/* TRANSLATORS: provides more information about the upgrade */
 					_("More information"), gpk_check_update_libnotify_cb, cupdate, NULL);
 	notify_notification_add_action (notification, "do-not-show-upgrade-available",
+					/* TRANSLATORS: hides forever */
 					_("Do not show this again"), gpk_check_update_libnotify_cb, cupdate, NULL);
 	ret = notify_notification_show (notification, &error);
 	if (!ret) {
@@ -995,6 +1037,7 @@ gpk_check_update_init (GpkCheckUpdate *cupdate)
 
 	cupdate->priv->notification_updates_available = NULL;
 	cupdate->priv->important_updates_array = NULL;
+	cupdate->priv->number_updates_critical_last_shown = 0;
 	cupdate->priv->sicon = gpk_smart_icon_new ();
 	gpk_smart_icon_set_priority (cupdate->priv->sicon, 2);
 
