@@ -35,12 +35,7 @@
 #include <fcntl.h>
 #include <glib/gi18n.h>
 #include <glade/glade.h>
-
-#include <pk-common.h>
-#include <pk-client.h>
-#include <pk-package-list.h>
-#include <pk-extra.h>
-#include <pk-enum.h>
+#include <packagekit-glib/packagekit.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
@@ -50,6 +45,7 @@
 #include "gpk-common.h"
 #include "gpk-gnome.h"
 #include "gpk-enum.h"
+#include "gpk-desktop.h"
 
 static void     gpk_client_dialog_class_init	(GpkClientDialogClass	*klass);
 static void     gpk_client_dialog_init		(GpkClientDialog	*dialog);
@@ -169,7 +165,7 @@ gpk_client_dialog_show_page (GpkClientDialog *dialog, GpkClientDialogPage page,
 	gpk_client_dialog_show_widget (dialog, "label_force_width", TRUE);
 
 	/* show */
-	widget = glade_xml_get_widget (dialog->priv->glade_xml, "window_client");
+	widget = glade_xml_get_widget (dialog->priv->glade_xml, "dialog_client");
 	gtk_widget_realize (widget);
 	gtk_window_present_with_time (GTK_WINDOW (widget), timestamp);
 
@@ -192,7 +188,7 @@ gpk_client_dialog_set_parent (GpkClientDialog *dialog, GdkWindow *window)
 	/* not sure what to do here, should probably unparent somehow */
 	if (window == NULL) {
 		egg_warning ("parent set NULL when already modal with another window, setting non-modal");
-		widget = glade_xml_get_widget (dialog->priv->glade_xml, "window_client");
+		widget = glade_xml_get_widget (dialog->priv->glade_xml, "dialog_client");
 		gtk_window_set_modal (GTK_WINDOW (widget), FALSE);
 		dialog->priv->has_parent = FALSE;
 
@@ -209,7 +205,7 @@ gpk_client_dialog_set_parent (GpkClientDialog *dialog, GdkWindow *window)
 		return FALSE;
 	}
 
-	widget = glade_xml_get_widget (dialog->priv->glade_xml, "window_client");
+	widget = glade_xml_get_widget (dialog->priv->glade_xml, "dialog_client");
 	gtk_widget_realize (widget);
 	gtk_window_set_modal (GTK_WINDOW (widget), TRUE);
 	gdk_window_set_transient_for (GTK_WIDGET (widget)->window, window);
@@ -229,7 +225,7 @@ gpk_client_dialog_set_window_title (GpkClientDialog *dialog, const gchar *title)
 	g_return_val_if_fail (title != NULL, FALSE);
 
 	egg_debug ("setting window title: %s", title);
-	widget = glade_xml_get_widget (dialog->priv->glade_xml, "window_client");
+	widget = glade_xml_get_widget (dialog->priv->glade_xml, "dialog_client");
 	gtk_window_set_title (GTK_WINDOW (widget), title);
 	return TRUE;
 }
@@ -246,7 +242,7 @@ gpk_client_dialog_set_window_icon (GpkClientDialog *dialog, const gchar *icon)
 	g_return_val_if_fail (icon != NULL, FALSE);
 
 	egg_debug ("setting window icon: %s", icon);
-	widget = glade_xml_get_widget (dialog->priv->glade_xml, "window_client");
+	widget = glade_xml_get_widget (dialog->priv->glade_xml, "dialog_client");
 	gtk_window_set_icon_name (GTK_WINDOW (widget), icon);
 	return TRUE;
 }
@@ -424,7 +420,7 @@ gpk_client_dialog_get_window (GpkClientDialog *dialog)
 
 	g_return_val_if_fail (GPK_IS_CLIENT_DIALOG (dialog), NULL);
 
-	widget = glade_xml_get_widget (dialog->priv->glade_xml, "window_client");
+	widget = glade_xml_get_widget (dialog->priv->glade_xml, "dialog_client");
 	return GTK_WINDOW (widget);
 }
 
@@ -467,7 +463,7 @@ gpk_client_dialog_close (GpkClientDialog *dialog)
 
 	g_return_val_if_fail (GPK_IS_CLIENT_DIALOG (dialog), FALSE);
 
-	widget = glade_xml_get_widget (dialog->priv->glade_xml, "window_client");
+	widget = glade_xml_get_widget (dialog->priv->glade_xml, "dialog_client");
 	gtk_widget_hide (widget);
 
 	if (dialog->priv->pulse_timer_id != 0) {
@@ -590,13 +586,12 @@ gpk_client_dialog_set_package_list (GpkClientDialog *dialog, const PkPackageList
 {
 	GtkTreeIter iter;
 	const PkPackageObj *obj;
-	PkExtra *extra;
-	const gchar *icon;
+	PkDesktop *desktop;
+	gchar *icon;
 	gchar *package_id;
 	gchar *text;
 	guint length;
 	guint i;
-	gboolean valid;
 	GtkWidget *widget;
 
 	gtk_list_store_clear (dialog->priv->store);
@@ -608,7 +603,7 @@ gpk_client_dialog_set_package_list (GpkClientDialog *dialog, const PkPackageList
 	else if (length > 1)
 		gtk_widget_set_size_request (widget, -1, 150);
 
-	extra = pk_extra_new ();
+	desktop = pk_desktop_new ();
 	length = pk_package_list_get_size (list);
 
 	/* add each well */
@@ -618,10 +613,9 @@ gpk_client_dialog_set_package_list (GpkClientDialog *dialog, const PkPackageList
 		package_id = pk_package_id_to_string (obj->id);
 
 		/* get the icon */
-		icon = pk_extra_get_icon_name (extra, obj->id->name);
-		valid = gpk_check_icon_valid (icon);
-		if (!valid)
-			icon = gpk_info_enum_to_icon_name (PK_INFO_ENUM_INSTALLED);
+		icon = gpk_desktop_guess_icon_name (desktop, obj->id->name);
+		if (icon == NULL)
+			icon = g_strdup (gpk_info_enum_to_icon_name (PK_INFO_ENUM_INSTALLED));
 
 		gtk_list_store_append (dialog->priv->store, &iter);
 		gtk_list_store_set (dialog->priv->store, &iter,
@@ -629,11 +623,12 @@ gpk_client_dialog_set_package_list (GpkClientDialog *dialog, const PkPackageList
 				    GPK_CLIENT_DIALOG_STORE_ID, package_id,
 				    GPK_CLIENT_DIALOG_STORE_TEXT, text,
 				    -1);
+		g_free (icon);
 		g_free (text);
 		g_free (package_id);
 	}
 
-	g_object_unref (extra);
+	g_object_unref (desktop);
 
 	return TRUE;
 }
@@ -664,6 +659,7 @@ gpk_dialog_treeview_for_package_list (GpkClientDialog *dialog)
 
 	/* column for name */
 	renderer = gtk_cell_renderer_text_new ();
+	/* TRANSLATORS: column for the package name */
 	column = gtk_tree_view_column_new_with_attributes (_("Name"), renderer,
 							   "markup", GPK_CLIENT_DIALOG_STORE_TEXT, NULL);
 	gtk_tree_view_column_set_sort_column_id (column, GPK_CLIENT_DIALOG_STORE_TEXT);
@@ -739,7 +735,7 @@ gpk_client_dialog_init (GpkClientDialog *dialog)
 	/* use custom widgets */
 	glade_set_custom_handler (gpk_client_create_custom_widget, dialog);
 
-	dialog->priv->glade_xml = glade_xml_new (PK_DATA "/gpk-client.glade", NULL, NULL);
+	dialog->priv->glade_xml = glade_xml_new (GPK_DATA "/gpk-client.glade", NULL, NULL);
 	dialog->priv->loop = g_main_loop_new (NULL, FALSE);
 	dialog->priv->response = GTK_RESPONSE_NONE;
 	dialog->priv->pulse_timer_id = 0;
@@ -758,7 +754,7 @@ gpk_client_dialog_init (GpkClientDialog *dialog)
 				 GTK_TREE_MODEL (dialog->priv->store));
 
 	/* common stuff */
-	widget = glade_xml_get_widget (dialog->priv->glade_xml, "window_client");
+	widget = glade_xml_get_widget (dialog->priv->glade_xml, "dialog_client");
 	g_signal_connect (widget, "delete_event", G_CALLBACK (gpk_client_dialog_window_delete_cb), dialog);
 	widget = glade_xml_get_widget (dialog->priv->glade_xml, "button_close");
 	g_signal_connect (widget, "clicked", G_CALLBACK (gpk_client_dialog_button_close_cb), dialog);
@@ -881,7 +877,7 @@ gpk_client_dialog_test (EggTest *test)
 	gpk_client_dialog_set_title (dialog, "Button press test with a really really long title");
 	gpk_client_dialog_set_message (dialog, "Please press Uninstall\n\nThis is a really really, really,\nreally long title <i>with formatting</i>");
 	gpk_client_dialog_set_image (dialog, "dialog-information");
-	gpk_client_dialog_set_action (dialog, _("Uninstall"));
+	gpk_client_dialog_set_action (dialog, "Uninstall");
 	gpk_client_dialog_show_page (dialog, GPK_CLIENT_DIALOG_PAGE_CONFIRM, 0, 0);
 	button = gpk_client_dialog_run (dialog);
 	if (button == GTK_RESPONSE_OK)
@@ -929,7 +925,7 @@ gpk_client_dialog_test (EggTest *test)
 	gpk_client_dialog_set_title (dialog, "Button press test");
 	gpk_client_dialog_set_message (dialog, "Please press Install if you can see the package list");
 	gpk_client_dialog_set_image (dialog, "dialog-information");
-	gpk_client_dialog_set_action (dialog, _("Install"));
+	gpk_client_dialog_set_action (dialog, "Install");
 	gpk_client_dialog_show_page (dialog, GPK_CLIENT_DIALOG_PAGE_CONFIRM, GPK_CLIENT_DIALOG_PACKAGE_LIST, 0);
 	button = gpk_client_dialog_run (dialog);
 	if (button == GTK_RESPONSE_OK)
