@@ -29,20 +29,45 @@
 #include <sys/types.h>
 #include <gtk/gtk.h>
 #include <dbus/dbus-glib.h>
-
 #include <polkit-gnome/polkit-gnome.h>
-
-#include <pk-package-id.h>
-#include <pk-enum.h>
-#include <pk-common.h>
+#include <packagekit-glib/packagekit.h>
+#include <locale.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
+#include "egg-console-kit.h"
 
 #include "gpk-enum.h"
 #include "gpk-common.h"
 #include "gpk-error.h"
 
+/**
+ * gpk_window_set_size_request:
+ **/
+gboolean
+gpk_window_set_size_request (GtkWindow *window, guint width, guint height)
+{
+	GdkScreen *screen;
+	guint screen_w;
+	guint screen_h;
+
+	/* check for tiny screen, like for instance a OLPC or EEE */
+	screen = gdk_screen_get_default ();
+	screen_w = gdk_screen_get_width (screen);
+	screen_h = gdk_screen_get_height (screen);
+	if (screen_w < width || screen_h < height) {
+		egg_debug ("using small form factor mode as %ix%i and requested %ix%i",
+			   screen_w, screen_h, width, height);
+		gtk_window_maximize (window);
+		return FALSE;
+	}
+
+	/* normal size laptop panel */
+	egg_debug ("using native mode: %ix%i", width, height);
+	gtk_widget_set_size_request (GTK_WIDGET(window), width, height);
+	return TRUE;
+}
+
 /**
  * gpk_package_id_format_twoline:
  *
@@ -145,59 +170,103 @@ gpk_package_get_name (const gchar *package_id)
  * gpk_check_privileged_user
  **/
 gboolean
-gpk_check_privileged_user (const gchar *application_name)
+gpk_check_privileged_user (const gchar *application_name, gboolean show_ui)
 {
+	EggConsoleKit *ck = NULL;
 	guint uid;
+	gboolean ret = FALSE;
 	gchar *message;
 	gchar *title;
+	GtkResponseType result;
+	GtkWidget *dialog;
 
 	uid = getuid ();
 	if (uid == 0) {
+		if (!show_ui)
+			goto out;
 		if (application_name == NULL)
+			/* TRANSLATORS: these tools cannot run as root (unknown name) */
 			title = g_strdup (_("This application is running as a privileged user"));
 		else
+			/* TRANSLATORS: cannot run as root user, and we display the applicaiton name */
 			title = g_strdup_printf (_("%s is running as a privileged user"), application_name);
 		message = g_strjoin ("\n",
-				     _("Running graphical applications as a privileged user should be avoided for security reasons."),
-				     _("Package management applications are security sensitive and therefore this application will now close."), NULL);
+				     /* TRANSLATORS: tell the user off */
+				     _("Package management applications are security sensitive."),
+				     /* TRANSLATORS: and explain why */
+				     _("Running graphical applications as a privileged user should be avoided for security reasons."), NULL);
+
+		/* give the user a choice */
+		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
+						 GTK_MESSAGE_WARNING, GTK_BUTTONS_CANCEL, "%s", title);
+		/* TRANSLATORS: button: allow the user to run this, even when insecure */
+		gtk_dialog_add_button (GTK_DIALOG(dialog), _("Continue Anyway"), GTK_RESPONSE_OK);
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG(dialog), "%s", message);
+		gtk_window_set_icon_name (GTK_WINDOW(dialog), GPK_ICON_SOFTWARE_INSTALLER);
+		result = gtk_dialog_run (GTK_DIALOG(dialog));
+		gtk_widget_destroy (dialog);
+
+		g_free (title);
+		g_free (message);
+
+		/* user did not agree to run insecure */
+		if (result != GTK_RESPONSE_OK) {
+			egg_warning ("uid=%i so closing", uid);
+			goto out;
+		}
+	}
+
+	/* talk to ConsoleKit */
+	ck = egg_console_kit_new ();
+
+	/* we are not local */
+	ret = egg_console_kit_is_local (ck);
+	if (!ret) {
+		if (!show_ui)
+			goto out;
+		if (application_name == NULL)
+			/* TRANSLATORS: the user is not sitting in front of the keyboard */
+			title = g_strdup (_("This application is running when the session is not local"));
+		else
+			/* TRANSLATORS: same, but we know the application name */
+			title = g_strdup_printf (_("%s is running when the session is not local"), application_name);
+		message = g_strjoin ("\n",
+				     /* TRANSLATORS: tell the user off */
+				     _("These applications should be run only when on local console."),
+				     /* TRANSLATORS: explain what to do */
+				     _("This normally indicates a bug with ConsoleKit or with the way your session has started."), NULL);
 		gpk_error_dialog (title, message, "");
 		g_free (title);
 		g_free (message);
-		egg_warning ("uid=%i so closing", uid);
-		return FALSE;
+		egg_warning ("not LOCAL so closing");
+		goto out;
 	}
-	return TRUE;
-}
 
-/**
- * gpk_check_icon_valid:
- *
- * Check icon actually exists and is valid in this theme
- **/
-gboolean
-gpk_check_icon_valid (const gchar *icon)
-{
-	GtkIconInfo *icon_info;
-	static GtkIconTheme *icon_theme = NULL;
-	gboolean ret = TRUE;
-
-	/* trivial case */
-	if (egg_strzero (icon))
-		return FALSE;
-
-	/* no unref required */
-	if (icon_theme == NULL)
-		icon_theme = gtk_icon_theme_get_default ();
-
-	/* default to 32x32 */
-	icon_info = gtk_icon_theme_lookup_icon (icon_theme, icon, 32, GTK_ICON_LOOKUP_USE_BUILTIN);
-	if (icon_info == NULL) {
-		egg_debug ("ignoring broken icon %s", icon);
-		ret = FALSE;
-	} else {
-		/* we only used this to see if it was valid */
-		gtk_icon_info_free (icon_info);
+	/* we are not active */
+	ret = egg_console_kit_is_active (ck);
+	if (!ret) {
+		if (!show_ui)
+			goto out;
+		if (application_name == NULL)
+			/* TRANSLATORS: the user is not active, i.e. is idle */
+			title = g_strdup (_("This application is running when the session is not active"));
+		else
+			/* TRANSLATORS: same, but we know the application name */
+			title = g_strdup_printf (_("%s is running when the session is not active"), application_name);
+		message = g_strjoin ("\n",
+				     /* TRANSLATORS: tell the user off */
+				     _("These applications should be run only when on active console."),
+				     /* TRANSLATORS: explain what to do */
+				     _("This normally indicates a bug with your remote desktop implementation."), NULL);
+		gpk_error_dialog (title, message, "");
+		g_free (title);
+		g_free (message);
+		egg_warning ("not ACTIVE so closing");
+		goto out;
 	}
+out:
+	if (ck != NULL)
+		g_object_unref (ck);
 	return ret;
 }
 
@@ -253,6 +322,7 @@ gpk_time_to_localised_string (guint time_secs)
 
 	/* is valid? */
 	if (time_secs == 0) {
+		/* TRANSLATORS: The actions has just literally happened */
 		timestring = g_strdup_printf (_("Now"));
 		return timestring;
 	}
@@ -262,6 +332,7 @@ gpk_time_to_localised_string (guint time_secs)
 
 	/* less than a minute */
 	if (seconds < 60) {
+		/* TRANSLATORS: time */
 		timestring = g_strdup_printf (ngettext ("%i second",
 							"%i seconds",
 							seconds), seconds);
@@ -292,6 +363,7 @@ gpk_time_to_localised_string (guint time_secs)
 	hours = minutes / 60;
 	minutes = minutes % 60;
 	if (minutes == 0) {
+		/* TRANSLATORS: time */
 		timestring = g_strdup_printf (ngettext (
 				"%i hour",
 				"%i hours",
@@ -342,6 +414,83 @@ gpk_strv_join_locale (gchar **array)
 	return NULL;
 }
 
+/**
+ * gpk_package_entry_completion_model_new:
+ *
+ * Creates a tree model containing completions from the system package list
+ **/
+static GtkTreeModel *
+gpk_package_entry_completion_model_new (void)
+{
+	PkPackageList *list;
+	guint i;
+	guint length;
+	gboolean ret;
+	const PkPackageObj *obj;
+	GHashTable *hash;
+	gpointer data;
+	GtkListStore *store;
+	GtkTreeIter iter;
+
+	store = gtk_list_store_new (1, G_TYPE_STRING);
+	hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
+	list = pk_package_list_new ();
+	ret = pk_obj_list_from_file (PK_OBJ_LIST(list), PK_SYSTEM_PACKAGE_LIST_FILENAME);
+	if (!ret) {
+		egg_warning ("no package list, try refreshing");
+		return NULL;
+	}
+
+	length = pk_package_list_get_size (list);
+	egg_debug ("loading %i autocomplete items", length);
+	for (i=0; i<length; i++) {
+		obj = pk_package_list_get_obj (list, i);
+		if (obj == NULL || obj->id == NULL || obj->id->name == NULL) {
+			egg_warning ("obj invalid!");
+			break;
+		}
+		data = g_hash_table_lookup (hash, (gpointer) obj->id->name);
+		if (data == NULL) {
+			/* append just the name */
+			g_hash_table_insert (hash, g_strdup (obj->id->name), GINT_TO_POINTER (1));
+			gtk_list_store_append (store, &iter);
+			gtk_list_store_set (store, &iter, 0, obj->id->name, -1);
+		}
+	}
+	g_hash_table_unref (hash);
+	g_object_unref (list);
+
+	return GTK_TREE_MODEL (store);
+}
+
+/**
+ * gpk_package_entry_completion_new:
+ *
+ * Creates a %GtkEntryCompletion containing completions from the system package list
+ **/
+GtkEntryCompletion *
+gpk_package_entry_completion_new (void)
+{
+	GtkEntryCompletion *completion;
+	GtkTreeModel *model;
+
+	/* create a tree model and use it as the completion model */
+	completion = gtk_entry_completion_new ();
+	model = gpk_package_entry_completion_model_new ();
+	if (model == NULL)
+		return completion;
+
+	/* set the model for our completion model */
+	gtk_entry_completion_set_model (completion, model);
+	g_object_unref (model);
+
+	/* use model column 0 as the text column */
+	gtk_entry_completion_set_text_column (completion, 0);
+	gtk_entry_completion_set_inline_completion (completion, TRUE);
+
+	return completion;
+}
+
 /***************************************************************************
  ***                          MAKE CHECK TESTS                           ***
  ***************************************************************************/
@@ -363,7 +512,7 @@ gpk_common_test (gpointer data)
 	 ************************************************************/
 	egg_test_title (test, "time zero");
 	text = gpk_time_to_localised_string (0);
-	if (text != NULL && strcmp (text, _("Now")) == 0)
+	if (text != NULL && strcmp (text, "Now") == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "failed, got %s", text);
@@ -372,7 +521,7 @@ gpk_common_test (gpointer data)
 	/************************************************************/
 	egg_test_title (test, "time 1s");
 	text = gpk_time_to_localised_string (1);
-	if (text != NULL && strcmp (text, _("1 second")) == 0) {
+	if (text != NULL && strcmp (text, "1 second") == 0) {
 		egg_test_success (test, NULL);
 	} else {
 		egg_test_failed (test, "failed, got %s", text);
@@ -382,7 +531,7 @@ gpk_common_test (gpointer data)
 	/************************************************************/
 	egg_test_title (test, "time 1m");
 	text = gpk_time_to_localised_string (1*60);
-	if (text != NULL && strcmp (text, _("1 minute")) == 0) {
+	if (text != NULL && strcmp (text, "1 minute") == 0) {
 		egg_test_success (test, NULL);
 	} else {
 		egg_test_failed (test, "failed, got %s", text);
@@ -392,7 +541,7 @@ gpk_common_test (gpointer data)
 	/************************************************************/
 	egg_test_title (test, "time 1h");
 	text = gpk_time_to_localised_string (1*60*60);
-	if (text != NULL && strcmp (text, _("1 hour")) == 0) {
+	if (text != NULL && strcmp (text, "1 hour") == 0) {
 		egg_test_success (test, NULL);
 	} else {
 		egg_test_failed (test, "failed, got %s", text);
@@ -402,7 +551,7 @@ gpk_common_test (gpointer data)
 	/************************************************************/
 	egg_test_title (test, "time 30s");
 	text = gpk_time_to_localised_string (30);
-	if (text != NULL && strcmp (text, _("30 seconds")) == 0) {
+	if (text != NULL && strcmp (text, "30 seconds") == 0) {
 		egg_test_success (test, NULL);
 	} else {
 		egg_test_failed (test, "failed, got %s", text);
@@ -412,7 +561,7 @@ gpk_common_test (gpointer data)
 	/************************************************************/
 	egg_test_title (test, "time 30m");
 	text = gpk_time_to_localised_string (30*60);
-	if (text != NULL && strcmp (text, _("30 minutes")) == 0) {
+	if (text != NULL && strcmp (text, "30 minutes") == 0) {
 		egg_test_success (test, NULL);
 	} else {
 		egg_test_failed (test, "failed, got %s", text);
@@ -422,7 +571,7 @@ gpk_common_test (gpointer data)
 	/************************************************************/
 	egg_test_title (test, "time 30m1s");
 	text = gpk_time_to_localised_string (30*60+1);
-	if (text != NULL && strcmp (text, _("30 minutes 1 second")) == 0) {
+	if (text != NULL && strcmp (text, "30 minutes 1 second") == 0) {
 		egg_test_success (test, NULL);
 	} else {
 		egg_test_failed (test, "failed, got %s", text);
@@ -432,7 +581,7 @@ gpk_common_test (gpointer data)
 	/************************************************************/
 	egg_test_title (test, "time 30m10s");
 	text = gpk_time_to_localised_string (30*60+10);
-	if (text != NULL && strcmp (text, _("30 minutes 10 seconds")) == 0) {
+	if (text != NULL && strcmp (text, "30 minutes 10 seconds") == 0) {
 		egg_test_success (test, NULL);
 	} else {
 		egg_test_failed (test, "failed, got %s", text);
