@@ -23,7 +23,7 @@
 
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <pk-enum.h>
+#include <packagekit-glib/packagekit.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
@@ -129,10 +129,12 @@ static const PkEnumMatch enum_role_icon_name[] = {
 	{PK_ROLE_ENUM_ACCEPT_EULA,		"pk-package-info"},
 	{PK_ROLE_ENUM_CANCEL,			"process-stop"},
 	{PK_ROLE_ENUM_DOWNLOAD_PACKAGES,	"pk-package-download"},
+	{PK_ROLE_ENUM_GET_CATEGORIES,		"pk-package-info"},
 	{PK_ROLE_ENUM_GET_DEPENDS,		"pk-package-info"},
 	{PK_ROLE_ENUM_GET_DETAILS,		"pk-package-info"},
 	{PK_ROLE_ENUM_GET_DISTRO_UPGRADES,	"pk-package-info"},
 	{PK_ROLE_ENUM_GET_FILES,		"pk-package-search"},
+	{PK_ROLE_ENUM_GET_OLD_TRANSACTIONS,	"pk-package-info"},
 	{PK_ROLE_ENUM_GET_PACKAGES,		"pk-package-search"},
 	{PK_ROLE_ENUM_GET_REPO_LIST,		"pk-package-sources"},
 	{PK_ROLE_ENUM_GET_REQUIRES,		"pk-package-info"},
@@ -151,7 +153,6 @@ static const PkEnumMatch enum_role_icon_name[] = {
 	{PK_ROLE_ENUM_SEARCH_FILE,		"pk-package-search"},
 	{PK_ROLE_ENUM_SEARCH_GROUP,		"pk-package-search"},
 	{PK_ROLE_ENUM_SEARCH_NAME,		"pk-package-search"},
-	{PK_ROLE_ENUM_SERVICE_PACK,		"pk-package-update"},
 	{PK_ROLE_ENUM_UPDATE_PACKAGES,		"pk-package-update"},
 	{PK_ROLE_ENUM_UPDATE_SYSTEM,		"system-software-update"},
 	{PK_ROLE_ENUM_WHAT_PROVIDES,		"pk-package-search"},
@@ -193,6 +194,7 @@ static const PkEnumMatch enum_group_icon_name[] = {
 	{PK_GROUP_ENUM_SYSTEM,			"applications-system"},
 	{PK_GROUP_ENUM_VIRTUALIZATION,		"computer"},
 	{PK_GROUP_ENUM_VENDOR,			"application-certificate"},
+	{PK_GROUP_ENUM_NEWEST,			"dialog-information"},
 	{0, NULL}
 };
 
@@ -322,7 +324,7 @@ gpk_error_enum_to_localised_text (PkErrorCodeEnum code)
 		text = _("An internal system error has occurred");
 		break;
 	case PK_ERROR_ENUM_GPG_FAILURE:
-		text = _("A security trust relationship is not present");
+		text = _("A security signature is not present");
 		break;
 	case PK_ERROR_ENUM_PACKAGE_NOT_INSTALLED:
 		text = _("The package is not installed");
@@ -406,10 +408,10 @@ gpk_error_enum_to_localised_text (PkErrorCodeEnum code)
 		text = _("Local install failed");
 		break;
 	case PK_ERROR_ENUM_BAD_GPG_SIGNATURE:
-		text = _("Bad GPG signature");
+		text = _("Bad security signature");
 		break;
 	case PK_ERROR_ENUM_MISSING_GPG_SIGNATURE:
-		text = _("Missing GPG signature");
+		text = _("Missing security signature");
 		break;
 	case PK_ERROR_ENUM_REPO_CONFIGURATION_ERROR:
 		text = _("Repository configuration invalid");
@@ -432,6 +434,9 @@ gpk_error_enum_to_localised_text (PkErrorCodeEnum code)
 	case PK_ERROR_ENUM_NO_MORE_MIRRORS_TO_TRY:
 		text = _("No more mirrors are available");
 		break;
+	case PK_ERROR_ENUM_NO_DISTRO_UPGRADE_DATA:
+		text = _("No distribution upgrade data is available");
+		break;
 	default:
 		egg_warning ("Unknown error");
 	}
@@ -463,11 +468,11 @@ gpk_error_enum_to_localised_message (PkErrorCodeEnum code)
 		break;
 	case PK_ERROR_ENUM_NOT_SUPPORTED:
 		text = _("The action is not supported by this backend.\n"
-			 "Please report a bug at " GPK_BUGZILLA_URL " as this should not have happened.");
+			 "Please report a bug in your distribution bugtracker as this should not have happened.");
 		break;
 	case PK_ERROR_ENUM_INTERNAL_ERROR:
 		text = _("A problem that we were not expecting has occurred.\n"
-			 "Please report this bug at " GPK_BUGZILLA_URL " with the error description.");
+			 "Please report this bug in your distribution bugtracker with the error description.");
 		break;
 	case PK_ERROR_ENUM_GPG_FAILURE:
 		text = _("A security trust relationship could not be made with software source.\n"
@@ -574,11 +579,11 @@ gpk_error_enum_to_localised_message (PkErrorCodeEnum code)
 			 "More information is available in the detailed report.");
 		break;
 	case PK_ERROR_ENUM_BAD_GPG_SIGNATURE:
-		text = _("The package signature could not be verified.");
+		text = _("The package security signature could not be verified.");
 		break;
 	case PK_ERROR_ENUM_MISSING_GPG_SIGNATURE:
-		text = _("The package signature was missing and this package is untrusted.\n"
-			 "This package was not signed with a GPG key when created.");
+		text = _("The package security signature is missing and this package is untrusted.\n"
+			 "This package was not signed when created.");
 		break;
 	case PK_ERROR_ENUM_REPO_CONFIGURATION_ERROR:
 		text = _("Repository configuration was invalid and could not be read.");
@@ -604,6 +609,10 @@ gpk_error_enum_to_localised_message (PkErrorCodeEnum code)
 		text = _("Required data could not be found on any of the configured software sources.\n"
 			 "There were no more download mirrors that could be tried.");
 		break;
+	case PK_ERROR_ENUM_NO_DISTRO_UPGRADE_DATA:
+		text = _("Required upgrade data could not be found in any of the configured software sources.\n"
+			 "The list of distribution upgrades will be unavailable.");
+		break;
 	default:
 		egg_warning ("Unknown error, please report a bug at " GPK_BUGZILLA_URL ".\n"
 			    "More information is available in the detailed report.");
@@ -707,10 +716,10 @@ gpk_message_enum_to_localised_text (PkMessageEnum message)
 		text = _("The priority was invalid");
 		break;
 	case PK_MESSAGE_ENUM_BACKEND_ERROR:
-		text = _("Generic backend error");
+		text = _("Backend warning");
 		break;
 	case PK_MESSAGE_ENUM_DAEMON_ERROR:
-		text = _("Generic daemon error");
+		text = _("Daemon warning");
 		break;
 	case PK_MESSAGE_ENUM_CACHE_BEING_REBUILT:
 		text = _("The package list cache is being rebuilt");
@@ -853,24 +862,31 @@ gpk_update_enum_to_localised_text (PkInfoEnum info, guint number)
 	gchar *text = NULL;
 	switch (info) {
 	case PK_INFO_ENUM_LOW:
+		/* TRANSLATORS: type of update */
 		text = g_strdup_printf (ngettext ("%i trivial update", "%i trivial updates", number), number);
 		break;
 	case PK_INFO_ENUM_NORMAL:
+		/* TRANSLATORS: type of update in the case that we don't have any data */
 		text = g_strdup_printf (ngettext ("%i update", "%i updates", number), number);
 		break;
 	case PK_INFO_ENUM_IMPORTANT:
+		/* TRANSLATORS: type of update */
 		text = g_strdup_printf (ngettext ("%i important update", "%i important updates", number), number);
 		break;
 	case PK_INFO_ENUM_SECURITY:
+		/* TRANSLATORS: type of update */
 		text = g_strdup_printf (ngettext ("%i security update", "%i security updates", number), number);
 		break;
 	case PK_INFO_ENUM_BUGFIX:
+		/* TRANSLATORS: type of update */
 		text = g_strdup_printf (ngettext ("%i bug fix update", "%i bug fix updates", number), number);
 		break;
 	case PK_INFO_ENUM_ENHANCEMENT:
+		/* TRANSLATORS: type of update */
 		text = g_strdup_printf (ngettext ("%i enhancement update", "%i enhancement updates", number), number);
 		break;
 	case PK_INFO_ENUM_BLOCKED:
+		/* TRANSLATORS: number of updates that cannot be installed due to deps */
 		text = g_strdup_printf (ngettext ("%i blocked update", "%i blocked updates", number), number);
 		break;
 	default:
@@ -1066,9 +1082,6 @@ gpk_role_enum_to_localised_present (PkRoleEnum role)
 	case PK_ROLE_ENUM_WHAT_PROVIDES:
 		text = _("Getting what provides");
 		break;
-	case PK_ROLE_ENUM_SERVICE_PACK:
-		text = _("Service pack");
-		break;
 	case PK_ROLE_ENUM_INSTALL_SIGNATURE:
 		text = _("Installing signature");
 		break;
@@ -1084,6 +1097,12 @@ gpk_role_enum_to_localised_present (PkRoleEnum role)
 	case PK_ROLE_ENUM_GET_DISTRO_UPGRADES:
 		text = _("Getting distribution upgrade information");
 		break;
+	case PK_ROLE_ENUM_GET_CATEGORIES:
+		text = _("Getting categories");
+		break;
+	case PK_ROLE_ENUM_GET_OLD_TRANSACTIONS:
+		text = _("Getting old transactions");
+		break;
 	default:
 		egg_warning ("role unrecognised: %s", pk_role_enum_to_text (role));
 	}
@@ -1131,22 +1150,19 @@ gpk_role_enum_to_localised_past (PkRoleEnum role)
 		text = _("Searched for package name");
 		break;
 	case PK_ROLE_ENUM_REMOVE_PACKAGES:
-		text = _("Removed package");
+		text = _("Removed packages");
 		break;
 	case PK_ROLE_ENUM_INSTALL_PACKAGES:
-		text = _("Installed package");
+		text = _("Installed packages");
 		break;
 	case PK_ROLE_ENUM_INSTALL_FILES:
-		text = _("Installed local file");
-		break;
-	case PK_ROLE_ENUM_SERVICE_PACK:
-		text = _("Updating from service pack");
+		text = _("Installed local files");
 		break;
 	case PK_ROLE_ENUM_REFRESH_CACHE:
 		text = _("Refreshed package cache");
 		break;
 	case PK_ROLE_ENUM_UPDATE_PACKAGES:
-		text = _("Updated package");
+		text = _("Updated packages");
 		break;
 	case PK_ROLE_ENUM_UPDATE_SYSTEM:
 		text = _("Updated system");
@@ -1190,6 +1206,12 @@ gpk_role_enum_to_localised_past (PkRoleEnum role)
 	case PK_ROLE_ENUM_GET_DISTRO_UPGRADES:
 		text = _("Got distribution upgrades");
 		break;
+	case PK_ROLE_ENUM_GET_CATEGORIES:
+		text = _("Got categories");
+		break;
+	case PK_ROLE_ENUM_GET_OLD_TRANSACTIONS:
+		text = _("Got old transactions");
+		break;
 	default:
 		egg_warning ("role unrecognised: %s", pk_role_enum_to_text (role));
 	}
@@ -1303,6 +1325,9 @@ gpk_group_enum_to_localised_text (PkGroupEnum group)
 	case PK_GROUP_ENUM_VENDOR:
 		text = _("Vendor");
 		break;
+	case PK_GROUP_ENUM_NEWEST:
+		text = _("Newest packages");
+		break;
 	case PK_GROUP_ENUM_UNKNOWN:
 		text = _("Unknown group");
 		break;
