@@ -37,15 +37,8 @@
 #include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
 #include <libnotify/notify.h>
-
 #include <polkit-gnome/polkit-gnome.h>
-
-#include <pk-control.h>
-#include <pk-client.h>
-#include <pk-common.h>
-#include <pk-task-list.h>
-#include <pk-connection.h>
-#include <pk-package-id.h>
+#include <packagekit-glib/packagekit.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
@@ -138,6 +131,7 @@ gpk_watch_refresh_tooltip (GpkWatch *watch)
 		}
 		/* don't fill the screen with a giant tooltip */
 		if (i > GPK_WATCH_MAXIMUM_TOOLTIP_LINES) {
+			/* TRANSLATORS: if the menu won't fit, inform the user there are a few more things waiting */
 			g_string_append_printf (status, _("(%i more tasks)"),
 						i - GPK_WATCH_MAXIMUM_TOOLTIP_LINES);
 			g_string_append_c (status, '\n');
@@ -283,7 +277,8 @@ gpk_watch_libnotify_cb (NotifyNotification *notification, gchar *action, gpointe
 		gconf_client_set_bool (watch->priv->gconf_client, GPK_CONF_NOTIFY_COMPLETED, FALSE, NULL);
 
 	} else if (egg_strequal (action, "show-error-details")) {
-		gpk_error_dialog (_("Error details"), NULL, watch->priv->error_details);
+		/* TRANSLATORS: The detailed error if the user clicks "more info" */
+		gpk_error_dialog (_("Error details"), _("Package manager error details"), watch->priv->error_details);
 
 	} else {
 		egg_warning ("unknown action id: %s", action);
@@ -363,17 +358,20 @@ gpk_watch_finished_cb (PkTaskList *tlist, PkClient *client, PkExitEnum exit, gui
 	}
 
 	if (role == PK_ROLE_ENUM_REMOVE_PACKAGES)
+		/* TRANSLATORS: This is the message in the libnotify body */
 		message = g_strdup_printf (_("Package '%s' has been removed"), text);
 	else if (role == PK_ROLE_ENUM_INSTALL_PACKAGES)
+		/* TRANSLATORS: This is the message in the libnotify body */
 		message = g_strdup_printf (_("Package '%s' has been installed"), text);
 	else if (role == PK_ROLE_ENUM_UPDATE_SYSTEM)
-		message = g_strdup ("System has been updated");
+		/* TRANSLATORS: This is the message in the libnotify body */
+		message = g_strdup (_("System has been updated"));
 
 	/* nothing of interest */
 	if (message == NULL)
 		goto out;
 
-	/* do the bubble */
+	/* TRANSLATORS: title: an action has finished, and we are showing the libnotify bubble */
 	notification = notify_notification_new (_("Task completed"), message, "help-browser", NULL);
 	notify_notification_set_timeout (notification, 5000);
 	notify_notification_set_urgency (notification, NOTIFY_URGENCY_LOW);
@@ -399,6 +397,7 @@ gpk_watch_error_code_cb (PkTaskList *tlist, PkClient *client, PkErrorCodeEnum er
 	gboolean ret;
 	GError *error = NULL;
 	const gchar *title;
+	gchar *title_prefix;
 	const gchar *message;
 	gboolean is_active;
 	gboolean value;
@@ -440,11 +439,15 @@ gpk_watch_error_code_cb (PkTaskList *tlist, PkClient *client, PkErrorCodeEnum er
 	g_free (watch->priv->error_details);
 	watch->priv->error_details = g_markup_escape_text (details, -1);
 
+	/* TRANSLATORS: Prefix to the title shown in the libnotify popup */
+	title_prefix = g_strdup_printf ("%s: %s", _("Package Manager"), title);
+
 	/* do the bubble */
-	notification = notify_notification_new (title, message, "help-browser", NULL);
+	notification = notify_notification_new (title_prefix, message, "help-browser", NULL);
 	notify_notification_set_timeout (notification, 15000);
 	notify_notification_set_urgency (notification, NOTIFY_URGENCY_LOW);
 	notify_notification_add_action (notification, "show-error-details",
+					/* TRANSLATORS: This is a link in a libnotify bubble that shows the detailed error */
 					_("Show details"), gpk_watch_libnotify_cb, watch, NULL);
 
 	ret = notify_notification_show (notification, &error);
@@ -452,6 +455,7 @@ gpk_watch_error_code_cb (PkTaskList *tlist, PkClient *client, PkErrorCodeEnum er
 		egg_warning ("error: %s", error->message);
 		g_error_free (error);
 	}
+	g_free (title_prefix);
 }
 
 /**
@@ -463,6 +467,7 @@ gpk_watch_message_cb (PkTaskList *tlist, PkClient *client, PkMessageEnum message
 	gboolean ret;
 	GError *error = NULL;
 	const gchar *title;
+	gchar *title_prefix;
 	const gchar *filename;
 	gchar *escaped_details;
 	gboolean value;
@@ -478,13 +483,15 @@ gpk_watch_message_cb (PkTaskList *tlist, PkClient *client, PkMessageEnum message
         }
 
 	title = gpk_message_enum_to_localised_text (message);
+	/* TRANSLATORS: Prefix to the title shown in the libnotify popup */
+	title_prefix = g_strdup_printf ("%s: %s", _("Package Manager"), title);
 	filename = gpk_message_enum_to_icon_name (message);
 
 	/* we need to format this */
 	escaped_details = g_markup_escape_text (details, -1);
 
 	/* do the bubble */
-	notification = notify_notification_new (title, escaped_details, "help-browser", NULL);
+	notification = notify_notification_new (title_prefix, escaped_details, "help-browser", NULL);
 	notify_notification_set_timeout (notification, NOTIFY_EXPIRES_NEVER);
 	notify_notification_set_urgency (notification, NOTIFY_URGENCY_LOW);
 	ret = notify_notification_show (notification, &error);
@@ -494,6 +501,7 @@ gpk_watch_message_cb (PkTaskList *tlist, PkClient *client, PkMessageEnum message
 	}
 
 	g_free (escaped_details);
+	g_free (title_prefix);
 }
 
 /**
@@ -531,6 +539,7 @@ gpk_watch_about_dialog_url_cb (GtkAboutDialog *about, const char *address, gpoin
 	g_free (cmdline);
 
 	if (!ret) {
+		/* TRANSLATORS: We couldn't launch the tool, normally a packaging problem */
 		gpk_error_dialog (_("Internal error"), _("Failed to show url"), error->message);
 		g_error_free (error);
 	}
@@ -613,7 +622,7 @@ gpk_watch_popup_menu_cb (GtkStatusIcon *status_icon,
 	g_return_if_fail (GPK_IS_WATCH (watch));
 	egg_debug ("icon right clicked");
 
-	/* About */
+	/* TRANSLATORS: this is the right click menu item */
 	item = gtk_image_menu_item_new_with_mnemonic (_("_About"));
 	image = gtk_image_new_from_icon_name (GTK_STOCK_ABOUT, GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
@@ -777,7 +786,7 @@ gpk_watch_activate_status_cb (GtkStatusIcon *status_icon,
 		widget = gtk_separator_menu_item_new ();
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), widget);
 
-		/* don't know if we want this */
+		/* TRANSLATORS: This is a right click menu item, and will refresh all the package lists */
 		widget = gtk_image_menu_item_new_with_mnemonic (_("_Refresh Software List"));
 		image = gtk_image_new_from_icon_name ("view-refresh", GTK_ICON_SIZE_MENU);
 		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (widget), image);
@@ -828,7 +837,7 @@ gpk_watch_activate_status_restart_cb (GtkStatusIcon *status_icon, GpkWatch *watc
 	widget = gtk_action_create_menu_item (GTK_ACTION (watch->priv->restart_action));
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), widget);
 
-	/* hide this option */
+	/* TRANSLATORS: This hides the 'restart required' icon */
 	widget = gtk_image_menu_item_new_with_mnemonic (_("_Hide this icon"));
 	image = gtk_image_new_from_icon_name ("dialog-information", GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (widget), image);
@@ -1121,6 +1130,7 @@ gpk_watch_init (GpkWatch *watch)
 	polkit_action_set_action_id (pk_action, "org.freedesktop.consolekit.system.restart");
 
 	restart_action = polkit_gnome_action_new_default ("restart-system", pk_action,
+							  /* TRANSLATORS: This button restarts the computer after an update */
 							  _("_Restart computer"), NULL);
 	g_object_set (restart_action,
 		      "no-icon-name", "gnome-shutdown",
